==> vtigercrm-5.2.1p2.tgz: modules/Accounts/language/es_es.lang.php <==
<?php
/***********************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 
 ********************************************************************************
*  Module       : Accounts
*  Language     : Español
*  Version      : 51
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2008-09-20
*  Author       : Joe Bordes JPL TSolucio, S. L.
* *******************************************************************************/

$mod_strings = array(
'LBL_MODULE_NAME'=>'Cuentas',
'LBL_MODULE_TITLE'=>'Cuentas: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Cuenta',
'LBL_LIST_FORM_TITLE'=>'Lista de Cuentas',
'LBL_NEW_FORM_TITLE'=>'Nueva Cuenta',
'LBL_MEMBER_ORG_FORM_TITLE'=>'Miembro de Organización ',
// Label for Top Accounts in Home Page, added for 4.2 GA
'LBL_TOP_ACCOUNTS'=>'Mis Cuentas Principales',
'LBL_TOP_AMOUNT'=>'Importe',
'LBL_LIST_ACCOUNT_NAME'=>'Cuenta',
'LBL_LIST_CITY'=>'Población',
'LBL_LIST_WEBSITE'=>'Página Web',
'LBL_LIST_STATE'=>'Provincia',
'LBL_LIST_PHONE'=>'Teléfono',
'LBL_LIST_EMAIL_ADDRESS'=>'Email',
'LBL_LIST_CONTACT_NAME'=>'Contacto',
'LBL_LIST_AMOUNT'=>'Cantidad Total',

//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_name' => 'LBL_LIST_ACCOUNT_NAME',
'db_website' => 'LBL_LIST_WEBSITE',
'db_billing_address_city' => 'LBL_LIST_CITY',

//END DON'T CONVERT

'LBL_ACCOUNT'=>'Cuenta:',
'LBL_ACCOUNT_NAME'=>'Nombre de la Cuenta',
'LBL_PHONE'=>'Teléfono:',
'LBL_WEBSITE'=>'Página Web:',
'LBL_FAX'=>'Fax:',
'LBL_TICKER_SYMBOL'=>'Ticker de bolsa:',
'LBL_OTHER_PHONE'=>'Tel. Otro:',
'LBL_ANY_PHONE'=>'Tel. Adicional:',
'LBL_MEMBER_OF'=>'Miembro de:',
'LBL_EMAIL'=>'Email:',
'LBL_EMPLOYEES'=>'Empleados:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Email (Otro):',
'LBL_ANY_EMAIL'=>'Email Alternativo:',
'LBL_OWNERSHIP'=>'Accionistas:',
'LBL_RATING'=>'Clasificación:',
'LBL_INDUSTRY'=>'Actividad:',
'LBL_SIC_CODE'=>'CIF:',
'LBL_TYPE'=>'Tipo:',
'LBL_ANNUAL_REVENUE'=>'Facturación Anual:',
'LBL_ADDRESS_INFORMATION'=>'Información de la Dirección',
'LBL_ACCOUNT_INFORMATION'=>'Información de la Cuenta',
'LBL_CUSTOM_INFORMATION'=>'Información Específica',
'LBL_BILLING_ADDRESS'=>'Dirección (Factura):',
'LBL_SHIPPING_ADDRESS'=>'Dirección (Envío):',
'LBL_ANY_ADDRESS'=>'Dirección (Alternativa):',
'LBL_CITY'=>'Población:',
'LBL_STATE'=>'Provincia:',
'LBL_POSTAL_CODE'=>'Código Postal:',
'LBL_COUNTRY'=>'País:',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción Adicional',
'LBL_DESCRIPTION'=>'Descripcion:',
'NTC_COPY_BILLING_ADDRESS'=>'Copiar Factura a Envío',
'NTC_COPY_SHIPPING_ADDRESS'=>'Copiar Envío a Factura',
'NTC_REMOVE_MEMBER_ORG_CONFIRMATION'=>'¿Está seguro que desea eliminar este registro de \"Miembro\"?',
'LBL_DUPLICATE'=>'Posibles cuentas duplicadas',
'MSG_DUPLICATE'=>'Creando esta cuenta puede duplicar una cuenta existente. Seleccione una cuenta de la lista de abajo o pulse en el boton Crear una Nueva Cuenta para crear una nueva cuenta con los datos introducidos.',

'LBL_INVITEE'=>'Contactos',
'ERR_DELETE_RECORD'=>'Debe especificar un registro para eliminar la empresa.',

'LBL_SELECT_ACCOUNT'=>'Seleccionar Cuenta',
'LBL_GENERAL_INFORMATION'=>'Información General',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Añadir Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidad',

'LBL_NEW_TASK'=>'Añadir Tarea',
'LBL_TASK_TITLE'=>'Tareas',
'LBL_NEW_CALL'=>'Añadir Llamada',
'LBL_CALL_TITLE'=>'Llamadas',
'LBL_NEW_MEETING'=>'Añadir Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',
'LBL_NEW_EMAIL'=>'Nuevo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_CONTACT'=>'Añadir Contacto',
'LBL_CONTACT_TITLE'=>'Contactos',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'Todo',
'LBL_PROSPECT'=>'Expectativa ',
'LBL_INVESTOR'=>'Inversor',
'LBL_RESELLER'=>'Revendedor',
'LBL_PARTNER'=>'Socio ',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Cuenta',
// Added for 4GA
'Account Name'=>'Nombre de la Cuenta',
'Phone'=>'Teléfono',
'Website'=>'Página Web',
'Fax'=>'Fax',
'Ticker Symbol'=>'Ticker de bolsa',
'Other Phone'=>'Tel. Alternativo',
'Member Of'=>'Miembro de',
'Email'=>'Email',
'Employees'=>'Empleados',
'Other Email'=>'Email (Alternativo)',
'Ownership'=>'Accionistas',
'Rating'=>'Importancia',
'industry'=>'Actividad',
'SIC Code'=>'CIF',
'Type'=>'Tipo',
'Annual Revenue'=>'Facturación Anual',
'Assigned To'=>'Asignado a',
'Billing Address'=>'Dirección (Factura)',
'Shipping Address'=>'Dirección (Envío)',
'Billing City'=>'Población (Factura)',
'Shipping City'=>'Población (Envío)',
'Billing State'=>'Provincia (Factura)',
'Shipping State'=>'Provincia (Envío)',
'Billing Code'=>'Código Postal (Factura)',
'Shipping Code'=>'Código Postal (Envío)',
'Billing Country'=>'País (Factura)',
'Shipping Country'=>'País (Envío)',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Fecha de Modificación',
'Description'=>'Descripción',
'Shipping Po Box'=>'Apdo. de Correos (Envío)',
'Billing Po Box'=>'Apdo. de Correos (Factura)',

//Added after 4.2 patch 2
'Email Opt Out'=>'No Enviar Emails',
'LBL_EMAIL_OPT_OUT'=>'No Enviar Emails:',

//Added after 5Alpha5
'Notify Owner'=>'Notificar al Propietario',

//Added for existing picklist entries

'--None--'=>'-----',

'Acquired'=>'Adquirido',
'Active'=>'Activo',
'Market Failed'=>'Mercado Inmaduro',
'Project Cancelled'=>'Cancelado',
'Shutdown'=>'Suspendido',

'Apparel'=>'Ropa',
'Banking'=>'Banca',
'Biotechnology'=>'Biotecnología',
'Chemicals'=>'Químicas',
'Communications'=>'Comunicaciones',
'Construction'=>'Construcción',
'Consulting'=>'Consultores',
'Education'=>'Educación',
'Electronics'=>'Electronica',
'Energy'=>'Energía',
'Engineering'=>'Ingeniería',
'Entertainment'=>'Entretenimiento',
'Environmental'=>'Medio Ambiente',
'Finance'=>'Finanzas',
'Food & Beverage'=>'Restauración',
'Government'=>'Gobierno',
'Healthcare'=>'Salud',
'Hospitality'=>'Hospital',
'Insurance'=>'Seguros',
'Machinery'=>'Mecánica',
'Manufacturing'=>'Manufacturas',
'Media'=>'Medios',
'Not For Profit'=>'ONG',
'Recreation'=>'Recreo',
'Retail'=>'Venta al por menor o Detall',
'Shipping'=>'Transporte',
'Technology'=>'Tecnología',
'Telecommunications'=>'Telecomunicaciones',
'Transportation'=>'Logística',
'Utilities'=>'Utilidades',
'Other'=>'Otros',

'Analyst'=>'Analista',
'Competitor'=>'Competencia',
'Customer'=>'Cliente',
'Integrator'=>'Integrador',
'Investor'=>'Inversor',
'Partner'=>'Socio',
'Press'=>'Prensa',
'Prospect'=>'Prospector',
'Reseller'=>'Revendedor',
'LBL_START_DATE' =>'Inicio',
'LBL_END_DATE' => 'Vencimiento',

// Added/Updated for vtiger CRM 5.0.4

//added to fix the issue #4081
'LBL_ACCOUNT_EXIST' => 'Cuenta ya Existente',

// mailer export
'LBL_MAILER_EXPORT' => 'Exportador de Email',
'LBL_MAILER_EXPORT_CONTACTS_TYPE'=>'Seleccione Contactos:',
'LBL_MAILER_EXPORT_CONTACTS_DESCR'=>'También puede seleccionar "Contactos" via "Campos Personalizados" u otros campos.',
'LBL_MAILER_EXPORT_RESULTS_TYPE'=>'Seleccione tipo de Exportación:',
'LBL_MAILER_EXPORT_RESULTS_DESCR'=>'Los datos se obtendrán de "Cuentas" y sus "Contactos" que provengan de la búsqueda previa.',

'LBL_EXPORT_RESULTS_EMAIL' => 'Exportar datos de Email',
'LBL_EXPORT_RESULTS_EMAIL_CORP'=>'Exportar datos de Email, usando "Email de la Cuenta" si no tiene Email de Contacto',
'LBL_EXPORT_RESULTS_FULL'=>'Exportar datos con Contactos, Email, Cuenta, Dirección, Teléfono, etc...',
'LBL_EXPORT_RESULTS_GO'=>'Exportado',
'LBL_MAILER_EXPORT_IGNORE' => '--Ignorar--',
'LBL_MAILER_EXPORT_CHECKED' =>'Marcado',
'LBL_MAILER_EXPORT_NOTCHECKED' => 'No Marcado',

// Added after 5.0.4 GA

//Module Sequence Numbering
'Account No'=>'Núm. Cuenta',
// END

// Account Hierarchy
'LBL_SHOW_ACCOUNT_HIERARCHY' => 'Mostrar Jerarquía de Cuentas',

);

?>

==> vtigercrm-5.3.0p0.tgz: modules/Accounts/language/es_es.lang.php <==
<?php
/***********************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 
 ********************************************************************************
*  Module       : Accounts
*  Language     : Español
*  Version      : 51
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2008-09-20
*  Author       : Joe Bordes JPL TSolucio, S. L.
* *******************************************************************************/

$mod_strings = array(
'LBL_MODULE_NAME'=>'Cuentas',
'LBL_MODULE_TITLE'=>'Cuentas: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Cuenta',
'LBL_LIST_FORM_TITLE'=>'Lista de Cuentas',
'LBL_NEW_FORM_TITLE'=>'Nueva Cuenta',
'LBL_MEMBER_ORG_FORM_TITLE'=>'Miembro de Organización ',
// Label for Top Accounts in Home Page, added for 4.2 GA
'LBL_TOP_ACCOUNTS'=>'Mis Cuentas Principales',
'LBL_TOP_AMOUNT'=>'Importe',
'LBL_LIST_ACCOUNT_NAME'=>'Cuenta',
'LBL_LIST_CITY'=>'Población',
'LBL_LIST_WEBSITE'=>'Página Web',
'LBL_LIST_STATE'=>'Provincia',
'LBL_LIST_PHONE'=>'Teléfono',
'LBL_LIST_EMAIL_ADDRESS'=>'Email',
'LBL_LIST_CONTACT_NAME'=>'Contacto',
'LBL_LIST_AMOUNT'=>'Cantidad Total',

//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_name' => 'LBL_LIST_ACCOUNT_NAME',
'db_website' => 'LBL_LIST_WEBSITE',
'db_billing_address_city' => 'LBL_LIST_CITY',

//END DON'T CONVERT

'LBL_ACCOUNT'=>'Cuenta:',
'LBL_ACCOUNT_NAME'=>'Nombre de la Cuenta',
'LBL_PHONE'=>'Teléfono:',
'LBL_WEBSITE'=>'Página Web:',
'LBL_FAX'=>'Fax:',
'LBL_TICKER_SYMBOL'=>'Ticker de bolsa:',
'LBL_OTHER_PHONE'=>'Tel. Otro:',
'LBL_ANY_PHONE'=>'Tel. Adicional:',
'LBL_MEMBER_OF'=>'Miembro de:',
'LBL_EMAIL'=>'Email:',
'LBL_EMPLOYEES'=>'Empleados:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Email (Otro):',
'LBL_ANY_EMAIL'=>'Email Alternativo:',
'LBL_OWNERSHIP'=>'Accionistas:',
'LBL_RATING'=>'Clasificación:',
'LBL_INDUSTRY'=>'Actividad:',
'LBL_SIC_CODE'=>'CIF:',
'LBL_TYPE'=>'Tipo:',
'LBL_ANNUAL_REVENUE'=>'Facturación Anual:',
'LBL_ADDRESS_INFORMATION'=>'Información de la Dirección',
'LBL_ACCOUNT_INFORMATION'=>'Información de la Cuenta',
'LBL_CUSTOM_INFORMATION'=>'Información Específica',
'LBL_BILLING_ADDRESS'=>'Dirección (Factura):',
'LBL_SHIPPING_ADDRESS'=>'Dirección (Envío):',
'LBL_ANY_ADDRESS'=>'Dirección (Alternativa):',
'LBL_CITY'=>'Población:',
'LBL_STATE'=>'Provincia:',
'LBL_POSTAL_CODE'=>'Código Postal:',
'LBL_COUNTRY'=>'País:',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción Adicional',
'LBL_DESCRIPTION'=>'Descripcion:',
'NTC_COPY_BILLING_ADDRESS'=>'Copiar Factura a Envío',
'NTC_COPY_SHIPPING_ADDRESS'=>'Copiar Envío a Factura',
'NTC_REMOVE_MEMBER_ORG_CONFIRMATION'=>'¿Está seguro que desea eliminar este registro de "Miembro"?',
'LBL_DUPLICATE'=>'Posibles cuentas duplicadas',
'MSG_DUPLICATE'=>'Creando esta cuenta puede duplicar una cuenta existente. Seleccione una cuenta de la lista de abajo o pulse en el boton Crear una Nueva Cuenta para crear una nueva cuenta con los datos introducidos.',

'LBL_INVITEE'=>'Contactos',
'ERR_DELETE_RECORD'=>'Debe especificar un registro para eliminar la empresa.',

'LBL_SELECT_ACCOUNT'=>'Seleccionar Cuenta',
'LBL_GENERAL_INFORMATION'=>'Información General',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Añadir Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidad',

'LBL_NEW_TASK'=>'Añadir Tarea',
'LBL_TASK_TITLE'=>'Tareas',
'LBL_NEW_CALL'=>'Añadir Llamada',
'LBL_CALL_TITLE'=>'Llamadas',
'LBL_NEW_MEETING'=>'Añadir Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',
'LBL_NEW_EMAIL'=>'Nuevo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_CONTACT'=>'Añadir Contacto',
'LBL_CONTACT_TITLE'=>'Contactos',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'Todo',
'LBL_PROSPECT'=>'Expectativa ',
'LBL_INVESTOR'=>'Inversor',
'LBL_RESELLER'=>'Revendedor',
'LBL_PARTNER'=>'Socio ',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Cuenta',
// Added for 4GA
'Account Name'=>'Nombre de la Cuenta',
'Phone'=>'Teléfono',
'Website'=>'Página Web',
'Fax'=>'Fax',
'Ticker Symbol'=>'Ticker de bolsa',
'Other Phone'=>'Tel. Alternativo',
'Member Of'=>'Miembro de',
'Email'=>'Email',
'Employees'=>'Empleados',
'Other Email'=>'Email (Alternativo)',
'Ownership'=>'Accionistas',
'Rating'=>'Importancia',
'industry'=>'Actividad',
'SIC Code'=>'CIF',
'Type'=>'Tipo',
'Annual Revenue'=>'Facturación Anual',
'Assigned To'=>'Asignado a',
'Billing Address'=>'Dirección (Factura)',
'Shipping Address'=>'Dirección (Envío)',
'Billing City'=>'Población (Factura)',
'Shipping City'=>'Población (Envío)',
'Billing State'=>'Provincia (Factura)',
'Shipping State'=>'Provincia (Envío)',
'Billing Code'=>'Código Postal (Factura)',
'Shipping Code'=>'Código Postal (Envío)',
'Billing Country'=>'País (Factura)',
'Shipping Country'=>'País (Envío)',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Fecha de Modificación',
'Description'=>'Descripción',
'Shipping Po Box'=>'Apdo. de Correos (Envío)',
'Billing Po Box'=>'Apdo. de Correos (Factura)',

//Added after 4.2 patch 2
'Email Opt Out'=>'No Enviar Emails',
'LBL_EMAIL_OPT_OUT'=>'No Enviar Emails:',

//Added after 5Alpha5
'Notify Owner'=>'Notificar al Propietario',

//Added for existing picklist entries

'--None--'=>'-----',

'Acquired'=>'Adquirido',
'Active'=>'Activo',
'Market Failed'=>'Mercado Inmaduro',
'Project Cancelled'=>'Cancelado',
'Shutdown'=>'Suspendido',

'Apparel'=>'Ropa',
'Banking'=>'Banca',
'Biotechnology'=>'Biotecnología',
'Chemicals'=>'Químicas',
'Communications'=>'Comunicaciones',
'Construction'=>'Construcción',
'Consulting'=>'Consultores',
'Education'=>'Educación',
'Electronics'=>'Electronica',
'Energy'=>'Energía',
'Engineering'=>'Ingeniería',
'Entertainment'=>'Entretenimiento',
'Environmental'=>'Medio Ambiente',
'Finance'=>'Finanzas',
'Food & Beverage'=>'Restauración',
'Government'=>'Gobierno',
'Healthcare'=>'Salud',
'Hospitality'=>'Hospital',
'Insurance'=>'Seguros',
'Machinery'=>'Mecánica',
'Manufacturing'=>'Manufacturas',
'Media'=>'Medios',
'Not For Profit'=>'ONG',
'Recreation'=>'Recreo',
'Retail'=>'Venta al por menor o Detall',
'Shipping'=>'Transporte',
'Technology'=>'Tecnología',
'Telecommunications'=>'Telecomunicaciones',
'Transportation'=>'Logística',
'Utilities'=>'Utilidades',
'Other'=>'Otros',

'Analyst'=>'Analista',
'Competitor'=>'Competencia',
'Customer'=>'Cliente',
'Integrator'=>'Integrador',
'Investor'=>'Inversor',
'Partner'=>'Socio',
'Press'=>'Prensa',
'Prospect'=>'Prospector',
'Reseller'=>'Revendedor',
'LBL_START_DATE' =>'Inicio',
'LBL_END_DATE' => 'Vencimiento',

// Added/Updated for vtiger CRM 5.0.4

//added to fix the issue #4081
'LBL_ACCOUNT_EXIST' => 'Cuenta ya Existente',

// mailer export
'LBL_MAILER_EXPORT' => 'Exportador de Email',
'LBL_MAILER_EXPORT_CONTACTS_TYPE'=>'Seleccione Contactos:',
'LBL_MAILER_EXPORT_CONTACTS_DESCR'=>'También puede seleccionar "Contactos" via "Campos Personalizados" u otros campos.',
'LBL_MAILER_EXPORT_RESULTS_TYPE'=>'Seleccione tipo de Exportación:',
'LBL_MAILER_EXPORT_RESULTS_DESCR'=>'Los datos se obtendrán de "Cuentas" y sus "Contactos" que provengan de la búsqueda previa.',

'LBL_EXPORT_RESULTS_EMAIL' => 'Exportar datos de Email',
'LBL_EXPORT_RESULTS_EMAIL_CORP'=>'Exportar datos de Email, usando "Email de la Cuenta" si no tiene Email de Contacto',
'LBL_EXPORT_RESULTS_FULL'=>'Exportar datos con Contactos, Email, Cuenta, Dirección, Teléfono, etc...',
'LBL_EXPORT_RESULTS_GO'=>'Exportado',
'LBL_MAILER_EXPORT_IGNORE' => '--Ignorar--',
'LBL_MAILER_EXPORT_CHECKED' =>'Marcado',
'LBL_MAILER_EXPORT_NOTCHECKED' => 'No Marcado',

// Added after 5.0.4 GA

//Module Sequence Numbering
'Account No'=>'Núm. Cuenta',
// END

// Account Hierarchy
'LBL_SHOW_ACCOUNT_HIERARCHY' => 'Mostrar Jerarquía de Cuentas',

);

?>
